pub struct ExternalDataStoreResolver { /* private fields */ }Expand description
A handle for resolving entity IDs from an ExternalDataStore.
Implementations
Sourceimpl ExternalDataStoreResolver
impl ExternalDataStoreResolver
Sourcepub fn resolve(
&self,
external_data: &RawExternalData<'_>,
) -> Option<ResolvedExternalData>
pub fn resolve( &self, external_data: &RawExternalData<'_>, ) -> Option<ResolvedExternalData>
Resolves the given raw external data.
The given raw external data is parsed and lookups are performed to resolve the underlying entity IDs (pod and
container). If the external data maps to valid, and the referenced entities exist, Some(ResolvedExternalData)
is returned, containing the entity IDs for both pod and container. Otherwise, if the raw external data is
invalid, or the referenced entities don’t exist, None is returned.
Sourcepub fn with_latest_snapshot<F>(&self, f: F)
pub fn with_latest_snapshot<F>(&self, f: F)
Executes the given function for each forward mapping in the latest snapshot.